@@ -79,7 +79,7 @@ if 0:
     _("interval|seventh")
     _("interval|octave")
     _("interval|ninth")
-    _("interval|decim")
+    _("interval|tenth")
     # translators: Only translate the word after interval| , and don't include
     # interval| in the translated string. So for Norwegians, translate
     # "interval|diminished" to "forminsket". Do similar for all strings
@@ -217,8 +217,8 @@ class Interval:
         sixth   m6 M6
         seventh m7 M7
         octave  p8
-        none    m9 M9
-        decim   m10 M10
+        ninth    m9 M9
+        tenth   m10 M10
         """
         # up or down
         s_orig = s[:]
