@@ -26,13 +26,17 @@ soundcard.end_export()
     Then set soundcard.synth back to what is was earlier.
 
 """
+import atexit
 import sys
 import os
+import subprocess
+import signal
 from mpd.track import Track, PercussionTrack
 from soundcardexceptions import SoundInitException
 from exporter import MidiExporter
 import src.cfg
 from src.osutils import *
+from src import osutils
 synth = None
 midiexporter = None
 
@@ -43,19 +47,43 @@ _saved_synth = None
 if sys.platform == 'win32':
     import winsound
 
+_mediaplayer = None
+def _kill_mediaplayer():
+    """
+    We need to do this atexit to avoid some text about an ignored
+    exception in Popen.
+    """
+    if _mediaplayer:
+        _mediaplayer.kill()
+        _mediaplayer.wait()
+atexit.register(_kill_mediaplayer)
+
 def play_mediafile(typeid, filename):
+    global _mediaplayer
     if sys.platform == 'win32' and typeid == 'wav':
         winsound.PlaySound(filename, winsound.SND_FILENAME | winsound.SND_ASYNC)
     else:
-        cmdline = src.cfg.get_string("sound/%s_player" % typeid)
+        args = [src.cfg.get_string("sound/%s_player" % typeid)]
+        # We only add %s_player_options if is is a non empty string,
+        # since args should not contain any empty strings.
+        if src.cfg.get_string("sound/%s_player_options"% typeid):
+            args.extend(
+             src.cfg.get_string("sound/%s_player_options"% typeid).split(" "))
+        found = False
+        for i, s in enumerate(args):
+            if '%s' in s:
+                args[i] = args[i] % os.path.abspath(filename)
+                found = True
+        if not found:
+            args.append(os.path.abspath(filename))
+        if _mediaplayer and _mediaplayer.poll() == None:
+            _mediaplayer.kill()
+            _mediaplaer  = None
         try:
-            # make the filename absolute, since we also use it in file URIs
-            run_external_program(
-                src.cfg.get_string("sound/%s_player" % typeid), "",
-                os.path.abspath(filename))
-        except OsUtilsException, e:
-            e.args = e.args + (_("Check the config for %(typeid)s files in the preferences window (Ctrl-F12).") % locals(),)
-            raise
+            _mediaplayer = osutils.Popen(args=args)
+        except OSError, e:
+            raise osutils.BinaryForMediaPlayerException(typeid,
+                src.cfg.get_string("sound/%s_player" % typeid), e)
 
 
 def initialise_winsynth(synthnum, verbose_init=0):
@@ -88,24 +116,6 @@ def initialise_using_fake_synth(verbose_init=None):
     import fakesynth
     synth = fakesynth.Synth(verbose_init)
 
-def play_note(patch, notelen, pitch, vel=64):
-    assert isinstance(patch, int) and 0 <= patch < 128
-    assert isinstance(notelen, int)
-    assert isinstance(pitch, int) and 0 <= pitch < 128
-    assert isinstance(vel, int) and 0 <= vel < 128
-    m = Track()
-    m.set_patch(patch)
-    m.note(notelen, pitch, vel)
-    synth.play_track(m)
-
-def play_perc(notelen, pitch, vel):
-    assert isinstance(notelen, int)
-    assert isinstance(pitch, int) and 0 <= pitch < 128
-    assert isinstance(vel, int) and 0 <= vel < 128
-    m = PercussionTrack()
-    m.note(notelen, pitch, vel)
-    synth.play_track(m)
-
 def start_export(filename):
     global midiexporter, _saved_synth, synth
     if not midiexporter:
@@ -334,12 +344,13 @@ percussion_names = [
         "Mute Triangle",
         "Open Triangle"]
 
+first_percussion_int_value = 35
 def percussionname_to_int(name):
     assert isinstance(name, basestring)
-    return percussion_names.index(name) + 35
+    return percussion_names.index(name) + first_percussion_int_value
 
 def int_to_percussionname(i):
     assert isinstance(i, int)
-    return percussion_names[i-35]
+    return percussion_names[i - first_percussion_int_value]
 
 
