@@ -32,11 +32,10 @@ if sys.platform == 'win32':
     try:
         from soundcard import winmidi
     except ImportError, e:
-        print "Loading winmidi.pyd failed:"
-        print e
+        print >> sys.stderr, "Loading winmidi.pyd failed:"
+        print >> sys.stderr, e
         winmidi = None
 
-
 class ConfigWindow(gtk.Dialog, cfg.ConfigUtils):
     def on_destroy(self, widget, e):
         self.m_app.m_ui.g_config_window.destroy()
@@ -70,7 +69,8 @@ class ConfigWindow(gtk.Dialog, cfg.ConfigUtils):
             gtk.Adjustment(self.get_int('config/default_bpm'), 10, 500, 1, 10))
         self.g_arpeggio_bpm = gu.nSpinButton('config', 'arpeggio_bpm',
             gtk.Adjustment(self.get_int('config/arpeggio_bpm'), 10, 500, 1, 10))
-        for text, widget in [("_Default:",self.g_default_bpm), ("A_rpeggio:",self.g_arpeggio_bpm)]:
+        for text, widget in [(_("_Default:") ,self.g_default_bpm), 
+                             (_("A_rpeggio:") ,self.g_arpeggio_bpm)]:
             label = gtk.Label(text)
             label.set_alignment(0.0, 0.5)
             label.set_use_underline(True)
