@@ -205,18 +205,18 @@ class Gui(abstract.IntervalGui):
     def get_interval_input_list(self):
         return self.get_list('intervals')
     def click_on_interval(self, mouse_button, interval, midi_int):
-        if mouse_button == 1:
+        if mouse_button in (1, self.keyboard_accel):
             # Do nothing if the user clicks on the anwer buttons or on
             # another input widget before the test has started.
             if self.m_t.m_app.m_test_mode and self.m_t.q_status == self.QSTATUS_NO:
                 self.g_flashbar.flash(_("Click 'Start test' to begin."))
                 return
-            # we have to ignore intervals greater than decime, because
+            # we have to ignore intervals greater than tenth, because
             # the statistics viewer can't handle it. It is no big deal
             # to fix it, but then the statistics can become almost unreadable
             # because of so many intervals.
             if not -17 < interval < 17:
-                self.g_flashbar.flash(_("Ignoring intervals greater than decim."))
+                self.g_flashbar.flash(_("Ignoring intervals greater than major tenth."))
                 self.g_input.forget_last_tone()
                 return
             if self.m_t.q_status == self.QSTATUS_NO:
