@@ -24,6 +24,7 @@ if __name__ == '__main__':
 
 debug_flag = ()
 
+import logging
 import copy
 import gobject
 import sys
@@ -309,10 +310,6 @@ class ElementBaseClass(tree.TreeNode):
         except AttributeError:
             ll = ""
         return "(%s %s children %s f:%s la:%s)" % (self.m_name, len(self.m_children), s, self.m_first, self.m_last)
-    def do_children(self):
-        for c in self.m_children:
-            print "EE", c
-            c.do_children()
     def get_as_string(self, level=0):
         """
         Return a string representation of the tree. This function is
@@ -390,7 +387,7 @@ class Element(ElementBaseClass):
             if buffer.tag_table.lookup(stylename):
                 buffer.apply_tag_by_name(stylename, it_a, it_b)
         else:
-            print "Element.apply_styles() ignoring:", self
+            logging.warning("htmlwidget.Element.apply_styles() ignoring: %s" % self)
         for c in self.m_children:
             c.apply_styles(buffer)
 
@@ -406,7 +403,6 @@ class B(Inline):
     def __init__(self, attrs):
         Inline.__init__(self, 'b', attrs)
     def children_to_str(self):
-        print "BOLD Children: '%s'" % (", ".join([n.children_to_str() for n in self.m_children]))
         return "<b>%s</b>" % ("".join([n.children_to_str() for n in self.m_children]))
 
 class HR(Block):
@@ -543,7 +539,7 @@ class NewHTMLParser(HTMLParser):
         self.m_charset = None
     def handle_starttag(self, tag, attrs):
         if 'start' in debug_flag:
-            print "start", tag, attrs, self.m_list_level, self.m_link_counter
+            logging.debug("htmlwidget: handle_starttag %s %s %s %s" % (tag, attrs, self.m_list_level, self.m_link_counter))
         if tag == 'html':
             self.m_tree = Block(tag, attrs)
             self.m_pointer = tree.Cursor(self.m_tree)
@@ -589,13 +585,13 @@ class NewHTMLParser(HTMLParser):
             self.m_pointer.goto_last_child()
     def handle_endtag(self, tag):
         if 'end' in debug_flag:
-            print "end", tag, self.m_list_level
+            logging.debug("htmlwidget.handle_endtag: %s %s" % (tag, self.m_list_level))
         if not self.m_pointer.get().m_name == tag:
             # <h1><a href="..."><img src="http://..."></a></h1>
             if self.m_pointer.get().m_name in self.startend_elements:
                 self.m_pointer.go_parent()
             else:
-                print "Warning: wrong end tag. Got '%s', expected '%s', ignoring:" % (tag, self.m_pointer.get().m_name)
+                logging.debug("handle_endtag: wrong end tag. Got '%s', expected '%s', ignoring:" % (tag, self.m_pointer.get().m_name))
         if tag == 'pre':
             self.in_pre -= 1
         if tag in self.list_elements:
@@ -603,8 +599,8 @@ class NewHTMLParser(HTMLParser):
         self.m_pointer.go_parent()
     def handle_data(self, data):
         if 'data' in debug_flag:
-            print "data '%s'" % data.replace("\n", "\\n")
-            print "type:", type(data), self.m_charset
+            logging.debug("handle_data: '%s'" % data.replace("\n", "\\n"))
+            logging.debug("type: %s %s" % (type(data), self.m_charset))
         if not data.strip():
             return
         if data:
@@ -627,7 +623,7 @@ class NewHTMLParser(HTMLParser):
                 if td.m_name in ('td', 'th'):
                     ret.append(td)
                 else:
-                    print "Not a td, ignoring:", td
+                    logging.debug("Not a td, ignoring: %s" % td)
             return ret
 
         def fill_table(cursor):
